Package: containr
Title: Containerize Your 'R' Project
Version: 0.1.3
Authors@R: 
    person("Erwin", "Lares", 
           email = "erwin.lares@wisc.edu", 
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-3284-828X"))
Description: Provides tools for containerizing 'R' projects. The core
    function, 'generate_dockerfile()', analyzes an 'R' project's environment
    and dependencies via an 'renv' lock file and generates a ready-to-use
    'Dockerfile' that encapsulates the computational setup. Designed to help
    researchers build portable, reproducible workflows that can be reliably
    shared, archived, and rerun across systems. See R Core Team (2025)
    <https://www.R-project.org/>, Ushey et al. (2025)
    <https://CRAN.R-project.org/package=renv>, and Docker Inc. (2025)
    <https://www.docker.com/>.
License: Apache License (>= 2)
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.2
URL: https://github.com/erwinlares/containr,
        https://erwinlares.github.io/containr/
BugReports: https://github.com/erwinlares/containr/issues
Suggests: spelling, testthat (>= 3.0.0), withr
Imports: cli, dplyr, glue, httr, purrr, readr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-26 04:45:17 UTC; lares
Author: Erwin Lares [aut, cre] (ORCID: <https://orcid.org/0000-0002-3284-828X>)
Maintainer: Erwin Lares <erwin.lares@wisc.edu>
Repository: CRAN
Date/Publication: 2026-04-26 06:50:02 UTC
Built: R 4.6.0; ; 2026-04-27 00:15:13 UTC; unix
